@@ -35,6 +35,14 @@ module.exports = function (fork) {
       .field("value", Number)
       .field("raw", String);
 
+    // Babylon 6 differs in AST from Flow
+    // same as NumberLiteralTypeAnnotation
+    def("NumericLiteralTypeAnnotation")
+      .bases("Type")
+      .build("value", "raw")
+      .field("value", Number)
+      .field("raw", String);
+
     def("StringTypeAnnotation")
       .bases("Type")
       .build();
@@ -178,9 +186,17 @@ module.exports = function (fork) {
       .build("argument")
       .field("argument", def("Type"));
 
+    def("ObjectTypeSpreadProperty")
+      .bases("Node")
+      .build("argument")
+      .field("argument", def("Type"));
+
     def("Identifier")
       .field("typeAnnotation", or(def("TypeAnnotation"), null), defaults["null"]);
 
+    def("ObjectPattern")
+      .field("typeAnnotation", or(def("TypeAnnotation"), null), defaults["null"]);
+
     def("TypeParameterDeclaration")
       .bases("Node")
       .build("params")
